@@ -17,18 +17,24 @@ alongTrackDistance <- function(p1, p2, p3, r=6378137) {
 	p2 <- p[,3:4,drop=FALSE]
 	p3 <- p[,5:6,drop=FALSE]
 	r = p[,7]
-	
+
 	tc <- bearing(p1, p2) * toRad
 	tcp <- bearing(p1, p3) * toRad
     dp <- distCosine(p1, p3, r=1)
 	xtr <- asin(sin(tcp-tc) * sin(dp))
 
 # +1/-1 for ahead/behind [lat1,lon1]
-	bearing <- sign(cos(tc - tcp))  
-	dist <- bearing * acos(cos(dp) / cos(xtr)) * r
-	
+	bearing <- sign(cos(tc - tcp))
+	angle <- cos(dp) / cos(xtr)
+
+# Fixing limits for the angle between [-1, 1] to avoid NaNs
+	angle[angle > 1] <- 1
+	angle[angle < -1] <- -1
+
+	dist <- bearing * acos(angle) * r
+
 	if (is.vector(dist)) { dist <- matrix(dist) }
 	colnames(dist) <- 'distance'
-	
+
 	return(abs(dist))
 }
