@@ -16,7 +16,7 @@ destPoint <- function(p, b, d, a=6378137, f=1/298.257223563, ...) {
 	p <- .pointsToMatrix(p)
 	p <- cbind(p[,1], p[,2], b, d)
 	
-	r <- .Call("_geodesic", as.double(p[,1]), as.double(p[,2]), as.double(p[,3]), as.double(p[,4]), as.double(a), as.double(f), PACKAGE='geosphere')
+	r <- .geodesic(as.double(p[,1]), as.double(p[,2]), as.double(p[,3]), as.double(p[,4]), as.double(a), as.double(f))
 	
 	r <- matrix(r, ncol=3, byrow=TRUE)
 	colnames(r) <- c('lon', 'lat', 'finalbearing')
