@@ -26,7 +26,7 @@
 geodesic <- function(p, azi, d, a=6378137, f=1/298.257223563, ...) { 
 	p <- .pointsToMatrix(p)
 	p <- cbind(p[,1], p[,2], azi, d)
-	r <- .Call("_geodesic", as.double(p[,1]), as.double(p[,2]), as.double(p[,3]), as.double(p[,4]), as.double(a), as.double(f), PACKAGE='geosphere')
+	r <- .geodesic(as.double(p[,1]), as.double(p[,2]), as.double(p[,3]), as.double(p[,4]), as.double(a), as.double(f))
 	r <- matrix(r, ncol=3, byrow=TRUE)
 	colnames(r) <- c('longitude', 'latitude', 'azimuth')
 	r
@@ -37,7 +37,7 @@ geodesic_inverse <- function(p1, p2, a=6378137, f=1/298.257223563, ...) {
 	p1 <- .pointsToMatrix(p1)
 	p2 <- .pointsToMatrix(p2)
 	p <- cbind(p1[,1], p1[,2], p2[,1], p2[,2])
-	r <- .Call("_inversegeodesic", as.double(p[,1]), as.double(p[,2]), as.double(p[,3]), as.double(p[,4]), as.double(a), as.double(f), PACKAGE='geosphere')
+	r <- .inversegeodesic(as.double(p[,1]), as.double(p[,2]), as.double(p[,3]), as.double(p[,4]), as.double(a), as.double(f))
 	r <- matrix(r, ncol=3, byrow=TRUE)
 	colnames(r) <- c('distance', 'azimuth1', 'azimuth2')
 	r
