@@ -26,6 +26,11 @@
  * - s and c prefixes mean sin and cos
  **********************************************************************/
 
+#include <algorithm> // std::min
+#include <cmath>
+#include <limits> // std::numeric_limits
+#include <memory> // std::swap
+//#include <__math/traits.h> // std::__math::isnan
 #include "Geodesic.h"
 #include "GeodesicLine.h"
 
